==> haskell-hasql-notifications-0.2.0.5-54-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-notifications.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-notifications
version:              0.2.0.5
visibility:           public
id:                   hasql-notifications-0.2.0.5-JUPBhIuYsR3FhkZoSziI9v
key:                  hasql-notifications-0.2.0.5-JUPBhIuYsR3FhkZoSziI9v
license:              BSD-3-Clause
copyright:            2020 Diogo Biazus
maintainer:           diogo@biazus.ca
author:               Diogo Biazus
homepage:             https://github.com/diogob/hasql-notifications
synopsis:             LISTEN/NOTIFY support for Hasql
description:
    Use PostgreSQL Asynchronous notification support with your Hasql Types.

category:             Hasql, Database, PostgreSQL
abi:                  cfc1806965e31f296a2bf621c2d64067
exposed:              True
exposed-modules:      Hasql.Notifications
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-notifications-0.2.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-notifications-0.2.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-notifications-0.2.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-notifications
hs-libraries:         HShasql-notifications-0.2.0.5-JUPBhIuYsR3FhkZoSziI9v
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hasql-1.5.0.5-HRwvYPLzYhM9K1MKHwukHo
    hasql-pool-0.5.2.2-VQByVsUzSiAMrUC4awYFl
    postgresql-libpq-0.9.4.3-9EKBGqszgJV2gOXf0kEzu1 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-notifications/html/hasql-notifications.haddock

haddock-html:         /usr/share/doc/haskell-hasql-notifications/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-notifications-0.2.0.5-76-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-notifications.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-notifications
version:              0.2.0.5
visibility:           public
id:                   hasql-notifications-0.2.0.5-JFYrIjS7v4O7KDb4zfoWk1
key:                  hasql-notifications-0.2.0.5-JFYrIjS7v4O7KDb4zfoWk1
license:              BSD-3-Clause
copyright:            2020 Diogo Biazus
maintainer:           diogo@biazus.ca
author:               Diogo Biazus
homepage:             https://github.com/diogob/hasql-notifications
synopsis:             LISTEN/NOTIFY support for Hasql
description:
    Use PostgreSQL Asynchronous notification support with your Hasql Types.

category:             Hasql, Database, PostgreSQL
abi:                  6fc887eb9b3d7a7cb11f4a3aca7804c0
exposed:              True
exposed-modules:      Hasql.Notifications
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-notifications-0.2.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-notifications-0.2.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-notifications-0.2.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-notifications
hs-libraries:         HShasql-notifications-0.2.0.5-JFYrIjS7v4O7KDb4zfoWk1
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hasql-1.5.0.5-GyUCDmolcLALaXTTlK3At6
    hasql-pool-0.5.2.2-BwHwxKHfI7IEs1vYZJSAQF
    postgresql-libpq-0.9.4.3-9EKBGqszgJV2gOXf0kEzu1 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-notifications/html/hasql-notifications.haddock

haddock-html:         /usr/share/doc/haskell-hasql-notifications/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
